@@ -21,6 +21,8 @@ import os
 import re
 import glob
 
+import six
+
 import gbp.command_wrappers as gbpc
 from gbp.errors import GbpError
 
@@ -83,7 +85,7 @@ def parse_archive_filename(filename):
             base_name = ".".join(split[:-1])
             (archive_fmt, compression) = (split[-1], None)
         else:
-            for (c, o) in compressor_opts.iteritems():
+            for (c, o) in six.iteritems(compressor_opts):
                 if o[1] == split[-1]:
                     base_name = ".".join(split[:-1])
                     compression = c
@@ -170,6 +172,8 @@ class PkgPolicy(object):
         ('foo-bar', '0.2')
         >>> PkgPolicy.guess_upstream_src_version('foo-bar-0.2.tlz')
         ('foo-bar', '0.2')
+        >>> PkgPolicy.guess_upstream_src_version('foo-bar_0.2.tar.gz')
+        ('foo-bar', '0.2')
         """
         version_chars = r'[a-zA-Z\d\.\~\-\:\+]'
         basename = parse_archive_filename(os.path.basename(filename))[0]
@@ -177,8 +181,9 @@ class PkgPolicy(object):
         version_filters = map ( lambda x: x % version_chars,
                            ( # Debian upstream tarball: package_'<version>.orig.tar.gz'
                              r'^(?P<package>[a-z\d\.\+\-]+)_(?P<version>%s+)\.orig',
+                             # Debian native: 'package_<version>.tar.gz'
+                             r'^(?P<package>[a-z\d\.\+\-]+)_(?P<version>%s+)',
                              # Upstream 'package-<version>.tar.gz'
-                             # or Debian native 'package_<version>.tar.gz'
                              # or directory 'package-<version>':
                              r'^(?P<package>[a-zA-Z\d\.\+\-]+)(-)(?P<version>[0-9]%s*)'))
         if extra_regex:
