@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2011 Guido Günther <agx@sigxcpu.org>
+# (C) 2011,2015 Guido Günther <agx@sigxcpu.org>
 # (C) 2012 Intel Corporation <markus.lehtonen@linux.intel.com>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ def parse_gbp_commands(info, cmd_tag, noarg_cmds, arg_cmds, filter_cmds=None):
     """
     body = []
     cmd_re = re.compile(r'^%s:\s*(?P<cmd>[a-z-]+)(\s+(?P<args>\S.*))?' %
-                            cmd_tag, flags=re.I)
+                        cmd_tag, flags=re.I)
     commands = {}
     for line in info['body'].splitlines():
         match = re.match(cmd_re, line)
@@ -105,14 +105,12 @@ def parse_gbp_commands(info, cmd_tag, noarg_cmds, arg_cmds, filter_cmds=None):
                 commands[cmd] = match.group('args')
             else:
                 gbp.log.warn("Ignoring unknown gbp-command '%s' in commit %s"
-                                % (line, info['id']))
+                             % (line, info['id']))
             if filter_cmds is None or cmd not in filter_cmds:
                 body.append(line)
         else:
             body.append(line)
     msg = '\n'.join(body)
-    # Add trailing newline if the originial body hat one
-    #msg += '\n' if info['body'] and info['body'][-1] == '\n' else ''
     return (commands, msg)
 
 
@@ -177,7 +175,7 @@ def write_patch_file(filename, commit_info, diff):
 
 
 def format_patch(outdir, repo, commit_info, series, numbered=True,
-                 path_exclude_regex=None, topic=''):
+                 path_exclude_regex=None, topic='', name=None):
     """Create patch of a single commit"""
 
     # Determine filename and path
@@ -188,12 +186,15 @@ def format_patch(outdir, repo, commit_info, series, numbered=True,
     suffix = '.patch'
     base_maxlen = 63 - len(num_prefix) - len(suffix)
     base = commit_info['patchname'][:base_maxlen]
-    filename = (num_prefix if numbered else '') + base + suffix
+    if name is not None:
+        filename = name
+    else:
+        filename = (num_prefix if numbered else '') + base + suffix
     filepath = os.path.join(outdir, filename)
     # Make sure that we don't overwrite existing patches in the series
     if filepath in series:
         presuffix = '-%d' % len(series)
-        base = base[:base_maxlen-len(presuffix)] + presuffix
+        base = base[:base_maxlen - len(presuffix)] + presuffix
         filename = (num_prefix if numbered else '') + base + suffix
         filepath = os.path.join(outdir, filename)
 
@@ -220,7 +221,7 @@ def format_diff(outdir, filename, repo, start, end, path_exclude_regex=None):
     info['subject'] = "Raw diff %s..%s" % (start, end)
     info['body'] = ("Raw diff between %s '%s' and\n%s '%s'\n" %
                     (repo.get_obj_type(start), start,
-                    repo.get_obj_type(end), end))
+                     repo.get_obj_type(end), end))
     if not filename:
         filename = '%s-to-%s.diff' % (start, end)
     filename = os.path.join(outdir, filename)
@@ -277,11 +278,11 @@ def apply_single_patch(repo, branch, patch, fallback_author, topic=None):
     gbp.log.info("Applied %s" % os.path.basename(patch.path))
 
 
-def apply_and_commit_patch(repo, patch, fallback_author, topic=None):
+def apply_and_commit_patch(repo, patch, fallback_author, topic=None, name=None):
     """apply a single patch 'patch', add topic 'topic' and commit it"""
     author = {'name': patch.author,
               'email': patch.email,
-              'date': patch.date }
+              'date': patch.date}
 
     patch_fn = os.path.basename(patch.path)
     if not (author['name'] and author['email']):
@@ -298,6 +299,8 @@ def apply_and_commit_patch(repo, patch, fallback_author, topic=None):
     msg = "%s\n\n%s" % (patch.subject, patch.long_desc)
     if topic:
         msg += "\nGbp-Pq: Topic %s" % topic
+    if name:
+        msg += "\nGbp-Pq: Name %s" % name
     commit = repo.commit_tree(tree, msg, [repo.head], author=author)
     repo.update_ref('HEAD', commit, msg="gbp-pq import %s" % patch.path)
 
