@@ -19,13 +19,13 @@ from . import context
 from . import testutils
 
 import os
-import logging
 import unittest
 
 from gbp.scripts.pq import generate_patches, export_patches
 import gbp.scripts.common.pq as pq
 import gbp.patch_series
 
+
 class TestApplyAndCommit(testutils.DebianGitTestRepo):
     """Test L{gbp.pq}'s apply_and_commit"""
 
@@ -40,7 +40,6 @@ class TestApplyAndCommit(testutils.DebianGitTestRepo):
         pq.apply_and_commit_patch(self.repo, patch, None)
         self.assertIn('foo', self.repo.list_files())
 
-
     def test_topic(self):
         """Test if setting a topic works"""
         patch = gbp.patch_series.Patch(_patch_path('foo.patch'))
@@ -49,6 +48,14 @@ class TestApplyAndCommit(testutils.DebianGitTestRepo):
         info = self.repo.get_commit_info('HEAD')
         self.assertIn('Gbp-Pq: Topic foobar', info['body'])
 
+    def test_name(self):
+        """Test if setting a name works"""
+        patch = gbp.patch_series.Patch(_patch_path('foo.patch'))
+
+        pq.apply_and_commit_patch(self.repo, patch, None, name='foobar')
+        info = self.repo.get_commit_info('HEAD')
+        self.assertIn('Gbp-Pq: Name foobar', info['body'])
+
     @unittest.skipIf(not os.path.exists('/usr/bin/dpkg'), 'Dpkg not found')
     def test_debian_missing_author(self):
         """
@@ -57,7 +64,7 @@ class TestApplyAndCommit(testutils.DebianGitTestRepo):
         """
         def _check_log(msg):
             self.assertEqual(msg, "Patch 'foo.patch' has no authorship "
-                         "information, using 'Guido Günther <gg@godiug.net>'")
+                             "information, using 'Guido Günther <gg@godiug.net>'")
 
         patch = gbp.patch_series.Patch(_patch_path('foo.patch'))
 
@@ -79,6 +86,7 @@ class TestApplyAndCommit(testutils.DebianGitTestRepo):
         self.assertEqual(info['author'].email, 'gg@godiug.net')
         self.assertIn('foo', self.repo.list_files())
 
+
 class TestApplySinglePatch(testutils.DebianGitTestRepo):
     """Test L{gbp.pq}'s apply_single_patch"""
 
@@ -94,6 +102,7 @@ class TestApplySinglePatch(testutils.DebianGitTestRepo):
         pq.apply_single_patch(self.repo, 'master', patch, None)
         self.assertIn('foo', self.repo.list_files())
 
+
 class TestWritePatch(testutils.DebianGitTestRepo):
     """Test L{gbp.pq}'s write_patch """
 
@@ -107,33 +116,39 @@ class TestWritePatch(testutils.DebianGitTestRepo):
     def test_generate_patches(self):
         """Test generation of patches"""
 
-        class opts: patch_numbers = False
+        class opts:
+            patch_numbers = False
 
+        d = context.new_tmpdir(__name__)
+        expected_paths = [os.path.join(str(d), 'gbptest', n) for n in
+                          ['added-foo.patch', 'patchname.diff']]
         # Add test file with topic:
         msg = ("added foo\n\n"
                "Gbp-Pq: Topic gbptest")
         self.add_file('foo', 'foo', msg)
+        msg = ("added bar\n\n"
+               "Gbp-Pq: Topic gbptest\n"
+               "Gbp-Pq: Name patchname.diff")
+        self.add_file('baz', 'baz', msg)
 
         # Write it out as patch and check it's existence
-        d = context.new_tmpdir(__name__)
-        patchfile = generate_patches(self.repo, 'HEAD^', 'HEAD', str(d),
-                                     opts)[0]
-        expected = os.path.join(str(d), 'gbptest', 'added-foo.patch')
-
-        self.assertEqual(os.path.basename(patchfile),
-                                          'added-foo.patch')
-        self.assertTrue(os.path.exists(expected))
-        logging.debug(open(expected).read())
+        patchfiles = generate_patches(self.repo, 'HEAD^^', 'HEAD', str(d),
+                                      opts)
+        for expected in expected_paths:
+            self.assertIn(expected, patchfiles)
+            self.assertTrue(os.path.exists(expected))
 
         # Reapply the patch to a new branch
-        self.repo.create_branch('testapply', 'HEAD^')
+        self.repo.create_branch('testapply', 'HEAD^^')
         self.repo.set_branch('testapply')
-        self.repo.apply_patch(expected)
+        for expected in expected_paths:
+            self.repo.apply_patch(expected)
         self.repo.commit_all("foo")
         diff = self.repo.diff('master', 'testapply')
         # Branches must be identical afterwards
         self.assertEqual('', diff)
 
+
 class TestExport(testutils.DebianGitTestRepo):
     class Options(object):
         drop = True
@@ -158,15 +173,15 @@ class TestExport(testutils.DebianGitTestRepo):
 class TestParseGbpCommand(unittest.TestCase):
     def test_empty_body(self):
         """Test command filtering with an empty body"""
-        info = { 'body': '' }
+        info = {'body': ''}
         (cmds, body) = pq.parse_gbp_commands(info, ['tag'], ['cmd1'], ['cmd2'])
         self.assertEquals(cmds, {})
         self.assertEquals(body, '')
 
     def test_noarg_cmd(self):
         orig_body = '\n'.join(["Foo",
-                          "tag: cmd1"])
-        info = { 'body': orig_body }
+                               "tag: cmd1"])
+        info = {'body': orig_body}
         (cmds, body) = pq.parse_gbp_commands(info, 'tag', ['cmd'], ['argcmd'])
         self.assertEquals(cmds, {'cmd': None})
         self.assertEquals(body, orig_body)
@@ -174,7 +189,7 @@ class TestParseGbpCommand(unittest.TestCase):
     def test_filter_cmd(self):
         orig_body = '\n'.join(["Foo",
                                "tag: cmd1"])
-        info = { 'body': orig_body }
+        info = {'body': orig_body}
         (cmds, body) = pq.parse_gbp_commands(info, 'tag', ['cmd'], ['argcmd'], ['cmd'])
         self.assertEquals(cmds, {'cmd': None})
         self.assertEquals(body, 'Foo')
