@@ -13,10 +13,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-"""Test L{gbp} config"""
+"""Test the L{gbp} config command"""
 
 import os
-import sys
 import unittest
 import gbp.scripts.config
 
