@@ -21,14 +21,12 @@ Module for testing individual command line tools of the git-buildpackage suite
 """
 
 import os
-import re
 import shutil
 import tempfile
-from StringIO import StringIO
 from nose import SkipTest
 from nose.tools import eq_, ok_     # pylint: disable=E0611
+from .. testutils import GbpLogTester
 
-import gbp.log
 from  gbp.git import GitRepository, GitRepositoryError
 
 class ComponentTestGitRepository(GitRepository):
@@ -76,7 +74,7 @@ class ComponentTestGitRepository(GitRepository):
                            "Consider doing 'git submodule update'" % __name__)
 
 
-class ComponentTestBase(object):
+class ComponentTestBase(GbpLogTester):
     """Base class for testing cmdline tools of git-buildpackage"""
 
     @classmethod
@@ -85,6 +83,12 @@ class ComponentTestBase(object):
         # Don't let git see that we're (possibly) under a git directory
         cls.orig_env = os.environ.copy()
         os.environ['GIT_CEILING_DIRECTORIES'] = os.getcwd()
+        # Create a top-level tmpdir for the test
+        cls._tmproot = tempfile.mkdtemp(prefix='gbp_%s_' % cls.__name__,
+                                        dir='.')
+        # Prevent local config files from messing up the tests
+        os.environ['GBP_CONF_FILES'] = '%(top_dir)s/.gbp.conf:' \
+                            '%(top_dir)s/debian/gbp.conf:%(git_dir)s/gbp.conf'
 
     @classmethod
     def teardown_class(cls):
@@ -92,19 +96,22 @@ class ComponentTestBase(object):
         # Return original environment
         os.environ.clear()
         os.environ.update(cls.orig_env)
+        # Remove top-level tmpdir
+        if not os.getenv("GBP_TESTS_NOCLEAN"):
+            shutil.rmtree(cls._tmproot)
 
     def __init__(self):
         """Object initialization"""
         self._orig_dir = None
         self._tmpdir = None
-        self._log = None
-        self._loghandler = None
+        GbpLogTester.__init__(self)
 
     def setup(self):
         """Test case setup"""
         # Change to a temporary directory
         self._orig_dir = os.getcwd()
-        self._tmpdir = tempfile.mkdtemp(prefix='gbp_%s_' % __name__, dir='.')
+        self._tmpdir = tempfile.mkdtemp(prefix='gbp_%s_' % __name__,
+                                        dir=self._tmproot)
         os.chdir(self._tmpdir)
 
         self._capture_log(True)
@@ -118,8 +125,18 @@ class ComponentTestBase(object):
 
         self._capture_log(False)
 
+    @staticmethod
+    def check_files(reference, filelist):
+        """Compare two file lists"""
+        extra = set(filelist) - set(reference)
+        missing = set(reference) - set(filelist)
+        assert_msg = "Unexpected files: %s, Missing files: %s" % \
+                        (list(extra), list(missing))
+        assert not extra and not missing, assert_msg
+
     @classmethod
-    def _check_repo_state(cls, repo, current_branch, branches, files=None):
+    def _check_repo_state(cls, repo, current_branch, branches, files=None,
+                          dirs=None):
         """Check that repository is clean and given branches exist"""
         branch = repo.branch
         eq_(branch, current_branch)
@@ -128,56 +145,21 @@ class ComponentTestBase(object):
         assert_msg = "Branches: expected %s, found %s" % (branches,
                                                           local_branches)
         eq_(set(local_branches), set(branches), assert_msg)
-        if files is not None:
+        if files is not None or dirs is not None:
             # Get files of the working copy recursively
-            local = set()
+            local_f = set()
+            local_d = set()
             for dirpath, dirnames, filenames in os.walk(repo.path):
                 # Skip git dir(s)
                 if '.git' in dirnames:
                     dirnames.remove('.git')
                 for filename in filenames:
-                    local.add(os.path.relpath(os.path.join(dirpath, filename),
-                                              repo.path))
+                    local_f.add(os.path.relpath(os.path.join(dirpath, filename),
+                                                repo.path))
                 for dirname in dirnames:
-                    local.add(os.path.relpath(os.path.join(dirpath, dirname),
-                                              repo.path) + '/')
-            extra = local - set(files)
-            ok_(not extra, "Unexpected files in repo: %s" % list(extra))
-            missing = set(files) - local
-            ok_(not missing, "Files missing from repo: %s" % list(missing))
-
-    def _capture_log(self, capture=True):
-        """ Capture log"""
-        if capture and self._log is None:
-            self._log = StringIO()
-            self._loghandler = gbp.log.GbpStreamHandler(self._log, False)
-            self._loghandler.addFilter(gbp.log.GbpFilter([gbp.log.WARNING,
-                                                          gbp.log.ERROR]))
-            for hdl in gbp.log.LOGGER.handlers:
-                gbp.log.LOGGER.removeHandler(hdl)
-            gbp.log.LOGGER.addHandler(self._loghandler)
-        elif self._log is not None:
-            gbp.log.LOGGER.removeHandler(self._loghandler)
-            self._loghandler.close()
-            self._loghandler = None
-            self._log.close()
-            self._log = None
-
-    def _get_log(self):
-        """Get the captured log output"""
-        self._log.seek(0)
-        return self._log.readlines()
-
-    def _check_log(self, linenum, regex):
-        """Check that the specified line on log matches expectations"""
-        if self._log is None:
-            raise Exception("BUG in unittests: no log captured!")
-        output = self._get_log()[linenum].strip()
-        ok_(re.match(regex, output),
-            "Log entry '%s' doesn't match '%s'" % (output, regex))
-
-    def _clear_log(self):
-        """Clear the mock strerr"""
-        if self._log is not None:
-            self._log.seek(0)
-            self._log.truncate()
+                    local_d.add(os.path.relpath(os.path.join(dirpath, dirname),
+                                                repo.path) + '/')
+            if files is not None:
+                cls.check_files(files, local_f)
+            if dirs is not None:
+                cls.check_files(dirs, local_d)
